@@ -1,4 +1,6 @@
-import os
+import warnings
+import astropy
+
 from pyspedas.utilities.dailynames import dailynames
 from pyspedas.utilities.download import download
 from pyspedas.analysis.time_clip import time_clip as tclip
@@ -64,7 +66,12 @@ def load(trange=['2013-11-5', '2013-11-6'],
     if downloadonly:
         return out_files
 
-    tvars = cdf_to_tplot(out_files, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, notplot=notplot)
+    with warnings.catch_warnings():
+        # for some reason, ACE CDFs throw ERFA warnings (likely while converting
+        # times inside astropy); we're ignoring these here
+        # see: https://github.com/astropy/astropy/issues/9603
+        warnings.simplefilter('ignore', astropy.utils.exceptions.ErfaWarning)
+        tvars = cdf_to_tplot(out_files, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, notplot=notplot)
     
     if notplot:
         return tvars
