@@ -1,7 +1,7 @@
 import os
 
 CONFIG = {'local_data_dir': 'equator-s_data/',
-          'remote_data_dir': 'https://spdf.sci.gsfc.nasa.gov/pub/data/equator-s/'}
+          'remote_data_dir': 'https://spdf.gsfc.nasa.gov/pub/data/equator-s/'}
 
 # override local data directory with environment variables
 if os.environ.get('SPEDAS_DATA_DIR'):
