@@ -1,4 +1,4 @@
-
+import logging
 import numpy as np
 from pytplot import store_data, options
 
@@ -41,7 +41,7 @@ def spd_pgs_make_tplot(name, x=None, y=None, z=None, units='', ylog=False, zlog=
     """
 
     if not isinstance(x, np.ndarray) or not isinstance(y, np.ndarray) or not isinstance(z, np.ndarray) :
-        print('Error, must specify x, y and z parameters')
+        logging.error('Error, must specify x, y and z parameters')
         return
 
     if ytitle is None:
