@@ -1,11 +1,15 @@
-
 import os
 import unittest
 from pyspedas.utilities.data_exists import data_exists
 from pytplot import get_data
 import pyspedas
 
+
 class LoadTestCases(unittest.TestCase):
+    def test_load_notplot(self):
+        sem_vars = pyspedas.poes.sem(notplot=True)
+        self.assertTrue('ted_ele_tel0_low_eflux' in sem_vars)
+
     def test_load_sem_data(self):
         sem_vars = pyspedas.poes.sem(time_clip=True)
         self.assertTrue(data_exists('ted_ele_tel0_low_eflux'))
@@ -23,5 +27,6 @@ class LoadTestCases(unittest.TestCase):
         files = pyspedas.poes.sem(downloadonly=True, probe='noaa19')
         self.assertTrue(os.path.exists(files[0]))
 
+
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
