@@ -1,6 +1,7 @@
-
 from pytplot import options
 from .load import load
+from pyspedas.utilities.datasets import find_datasets
+
 
 def mag(trange=['2020-06-01', '2020-06-02'],
         datatype='rtn-normal', 
@@ -92,6 +93,7 @@ def mag(trange=['2020-06-01', '2020-06-02'],
 
     return mag_vars
 
+
 def rpw(trange=['2020-06-15', '2020-06-16'],
         datatype='hfr-surv', 
         level='l2', 
@@ -192,6 +194,7 @@ def rpw(trange=['2020-06-15', '2020-06-16'],
     """
     return load(instrument='rpw', trange=trange, level=level, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
 
+
 def swa(trange=['2020-07-22', '2020-07-23'],
         datatype='pas-eflux', 
         level='l2', 
@@ -266,6 +269,7 @@ def swa(trange=['2020-07-22', '2020-07-23'],
 
     return loaded_vars
 
+
 def epd(trange=['2020-06-14', '2020-06-15'],
         datatype='step', 
         mode='hcad', 
@@ -334,3 +338,6 @@ def epd(trange=['2020-06-14', '2020-06-15'],
     """
     return load(instrument='epd', trange=trange, level=level, datatype=datatype, mode=mode, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
 
+
+def datasets(instrument=None, label=True):
+    return find_datasets(mission='Solar Orbiter', instrument=instrument, label=label)
