@@ -1,5 +1,6 @@
-
 from .load import load
+from pyspedas.utilities.datasets import find_datasets
+
 
 def vhm(trange=['2009-01-01', '2009-01-02'],
         datatype='1min', 
@@ -14,7 +15,8 @@ def vhm(trange=['2009-01-01', '2009-01-02'],
     """
     This function loads data from the VHM/FGM experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -56,7 +58,8 @@ def vhm(trange=['2009-01-01', '2009-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -75,7 +78,8 @@ def swoops(trange=['2009-01-01', '2009-01-02'],
     """
     This function loads data from the SWOOPS experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -117,7 +121,8 @@ def swoops(trange=['2009-01-01', '2009-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -136,7 +141,8 @@ def swics(trange=['2009-01-01', '2009-01-02'],
     """
     This function loads data from the SWICS experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -178,7 +184,8 @@ def swics(trange=['2009-01-01', '2009-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -197,7 +204,8 @@ def urap(trange=['2003-01-01', '2003-01-02'],
     """
     This function loads data from the URAP experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -239,7 +247,8 @@ def urap(trange=['2003-01-01', '2003-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -258,7 +267,8 @@ def epac(trange=['1996-01-01', '1996-01-02'],
     """
     This function loads data from the EPAC experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -300,7 +310,8 @@ def epac(trange=['1996-01-01', '1996-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -319,7 +330,8 @@ def hiscale(trange=['2003-01-01', '2003-01-02'],
     """
     This function loads data from the HI-SCALE experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -361,7 +373,8 @@ def hiscale(trange=['2003-01-01', '2003-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -380,7 +393,8 @@ def cospin(trange=['2003-01-01', '2003-01-02'],
     """
     This function loads data from the COSPIN experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -422,7 +436,8 @@ def cospin(trange=['2003-01-01', '2003-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -441,7 +456,8 @@ def grb(trange=['2003-01-01', '2003-01-02'],
     """
     This function loads data from the GRB experiment from the Ulysses mission
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -483,8 +499,13 @@ def grb(trange=['2003-01-01', '2003-01-02'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
     return load(instrument='grb', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+
+
+def datasets(instrument=None, label=True):
+    return find_datasets(mission='Ulysses', instrument=instrument, label=label)
